# Python Visualization

Following are files to support the Python visualization.

## `smoothing_types.py`

```python
<!-- cmdrun cat smoothing_types.py -->
```

## `smoothing_test.py`

```python
<!-- cmdrun cat smoothing_test.py -->
```

## `smoothing.py`

```python
<!-- cmdrun cat smoothing.py -->
```

## `smoothing_examples.py`

```python
<!-- cmdrun cat smoothing_examples.py -->
```

## `smoothing_figures.py`

```python
<!-- cmdrun cat smoothing_figures.py -->
```
